@@ -1,7 +1,7 @@
 #!/bin/bash
 
 sudo dnf install fedora-packager fedora-review rubygems-devel \
-    rubygem-rspec rubygem-gem2rpm git -y
+    rubygem-rspec rubygem-gem2rpm git vim -y
 sudo usermod -a -G mock vagrant
 newgrp
 echo 'jaymzh' > ~vagrant/.fedora.upn
@@ -22,4 +22,5 @@ EOF
 cat >> ~vagrant/.bashrc <<'EOF'
 source /usr/share/git-core/contrib/completion/git-prompt.sh
 export PS1="[\u@\h\$(__git_ps1) \W]\$ "
+export EDITOR=vim
 EOF
