@@ -1,23 +1,18 @@
-# For Ruby packages, Debian autopkgtest runs in an environment where
-# gem2deb-test-runner removes the lib directory from the source tree, so
-# the specs have to be able to load the installed copy instead.
-#
-# add '../lib' to the front of the path, so that when requiring modules, the
-# ones in '../lib' are still going to be used if available, but we can fall
-# back to an installed module
-#
-# See https://wiki.debian.org/Teams/Ruby/Packaging/Tests#Case_eight:_autopkgtest_failure
-$LOAD_PATH.unshift File.expand_path('../lib', __dir__)
-require 'sugarjar/commands'
+require_relative '../lib/sugarjar/commands'
+require_relative '../lib/sugarjar/util'
 
 describe 'SugarJar::Commands' do
+  let(:sj) do
+    SugarJar::Commands.new({ 'no_change' => true })
+  end
+
   context '#set_commit_template' do
     it 'Does nothing if not in repo' do
       expect(SugarJar::RepoConfig).to receive(:config).and_return(
         { 'commit_template' => '.commit_template.txt' },
       )
       sj = SugarJar::Commands.new({ 'no_change' => true })
-      expect(sj).to receive(:in_repo).and_return(false)
+      expect(SugarJar::Util).to receive(:in_repo?).and_return(false)
       expect(SugarJar::Log).to receive(:debug).with(/Skipping/)
       sj.send(:set_commit_template)
     end
@@ -27,8 +22,8 @@ describe 'SugarJar::Commands' do
         { 'commit_template' => '.commit_template.txt' },
       )
       sj = SugarJar::Commands.new({ 'no_change' => true })
-      expect(sj).to receive(:in_repo).and_return(true)
-      expect(sj).to receive(:repo_root).and_return('/nonexistent')
+      expect(SugarJar::Util).to receive(:in_repo?).and_return(true)
+      expect(SugarJar::Util).to receive(:repo_root).and_return('/nonexistent')
       expect(File).to receive(:exist?).
         with('/nonexistent/.commit_template.txt').and_return(false)
       expect(SugarJar::Log).to receive(:fatal).with(/exist/)
@@ -40,8 +35,8 @@ describe 'SugarJar::Commands' do
         { 'commit_template' => '.commit_template.txt' },
       )
       sj = SugarJar::Commands.new({ 'no_change' => true })
-      expect(sj).to receive(:in_repo).and_return(true)
-      expect(sj).to receive(:repo_root).and_return('/nonexistent')
+      expect(SugarJar::Util).to receive(:in_repo?).and_return(true)
+      expect(SugarJar::Util).to receive(:repo_root).and_return('/nonexistent')
       expect(File).to receive(:exist?).
         with('/nonexistent/.commit_template.txt').and_return(true)
       so = double('shell_out')
@@ -57,8 +52,8 @@ describe 'SugarJar::Commands' do
         { 'commit_template' => '.commit_template.txt' },
       )
       sj = SugarJar::Commands.new({ 'no_change' => true })
-      expect(sj).to receive(:in_repo).and_return(true)
-      expect(sj).to receive(:repo_root).and_return('/nonexistent')
+      expect(SugarJar::Util).to receive(:in_repo?).and_return(true)
+      expect(SugarJar::Util).to receive(:repo_root).and_return('/nonexistent')
       expect(File).to receive(:exist?).
         with('/nonexistent/.commit_template.txt').and_return(true)
       so = double('shell_out')
@@ -77,8 +72,8 @@ describe 'SugarJar::Commands' do
         { 'commit_template' => '.commit_template.txt' },
       )
       sj = SugarJar::Commands.new({ 'no_change' => true })
-      expect(sj).to receive(:in_repo).and_return(true)
-      expect(sj).to receive(:repo_root).and_return('/nonexistent')
+      expect(SugarJar::Util).to receive(:in_repo?).and_return(true)
+      expect(SugarJar::Util).to receive(:repo_root).and_return('/nonexistent')
       expect(File).to receive(:exist?).
         with('/nonexistent/.commit_template.txt').and_return(true)
       so = double('shell_out')
@@ -92,11 +87,22 @@ describe 'SugarJar::Commands' do
     end
   end
 
-  context '#extract_org' do
-    let(:sj) do
-      SugarJar::Commands.new({ 'no_change' => true })
+  context '#fprefix' do
+    it 'Adds prefixes when needed' do
+      sj = SugarJar::Commands.new(
+        { 'no_change' => true, 'feature_prefix' => 'someuser/' },
+      )
+      expect(sj).to receive(:all_local_branches).and_return(['/nonexistent'])
+      expect(sj.send(:fprefix, 'test')).to eq('someuser/test')
     end
 
+    it 'Does not add prefixes when not needed' do
+      sj = SugarJar::Commands.new({ 'no_change' => true })
+      expect(sj.send(:fprefix, 'test')).to eq('test')
+    end
+  end
+
+  context '#extract_org' do
     [
       # ssh
       'git@github.com:org/repo.git',
@@ -104,20 +110,33 @@ describe 'SugarJar::Commands' do
       'http://github.com/org/repo.git',
       # https
       'https://github.com/org/repo.git',
-      # hub
+      # gh
       'org/repo',
     ].each do |url|
-      it "detects the org from #{url}" do
+      it "extracts the org from #{url}" do
         expect(sj.send(:extract_org, url)).to eq('org')
       end
     end
   end
 
-  context '#forked_repo' do
-    let(:sj) do
-      SugarJar::Commands.new({ 'no_change' => true })
+  context '#extract_repo' do
+    [
+      # ssh
+      'git@github.com:org/repo.git',
+      # http
+      'http://github.com/org/repo.git',
+      # https
+      'https://github.com/org/repo.git',
+      # gh
+      'org/repo',
+    ].each do |url|
+      it "extracts the repo from #{url}" do
+        expect(sj.send(:extract_repo, url)).to eq('repo')
+      end
     end
+  end
 
+  context '#forked_repo' do
     [
       # ssh
       'git@github.com:org/repo.git',
@@ -136,10 +155,6 @@ describe 'SugarJar::Commands' do
   end
 
   context '#canonicalize_repo' do
-    let(:sj) do
-      SugarJar::Commands.new({ 'no_change' => true })
-    end
-
     [
       # ssh
       'git@github.com:org/repo.git',
@@ -153,26 +168,11 @@ describe 'SugarJar::Commands' do
       end
     end
 
-    # hub
+    # gh
     url = 'org/repo'
     it "canonicalizes short name #{url}" do
       expect(sj.send(:canonicalize_repo, url)).
         to eq('git@github.com:org/repo.git')
     end
   end
-
-  context '#fprefix' do
-    it 'Adds prefixes when needed' do
-      sj = SugarJar::Commands.new(
-        { 'no_change' => true, 'feature_prefix' => 'someuser/' },
-      )
-      expect(sj).to receive(:all_local_branches).and_return(['/nonexistent'])
-      expect(sj.send(:fprefix, 'test')).to eq('someuser/test')
-    end
-
-    it 'Does not add prefixes when not needed' do
-      sj = SugarJar::Commands.new({ 'no_change' => true })
-      expect(sj.send(:fprefix, 'test')).to eq('test')
-    end
-  end
 end
